import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { d as differenceInMinutes } from './ChatHead.js';
import { s as smoothScrollToBottom } from './scroll.js';
import { u as useLanguage } from './index2.js';
import { g as getUserPreferences, s as setPreference } from './user-prefs.js';
import { g as gracefulStorage } from './graceful-storage.js';
import { d as defineCustomElement$9 } from './dyte-button2.js';
import { d as defineCustomElement$8 } from './dyte-emoji-picker2.js';
import { d as defineCustomElement$7 } from './dyte-file-message2.js';
import { d as defineCustomElement$6 } from './dyte-icon2.js';
import { d as defineCustomElement$5 } from './dyte-image-message2.js';
import { d as defineCustomElement$4 } from './dyte-spinner2.js';
import { d as defineCustomElement$3 } from './dyte-text-message2.js';
import { d as defineCustomElement$2 } from './dyte-tooltip2.js';

const dyteChatCss = ".scrollbar{scrollbar-width:thin;scrollbar-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))\n    var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar{height:var(--dyte-space-1\\.5, 6px);width:var(--dyte-space-1\\.5, 6px);border-radius:9999px;background-color:var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar-thumb{border-radius:9999px;background-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))}:host{display:flex;height:100%;width:100%;flex-direction:column;font-family:var(--dyte-font-family, sans-serif);font-size:14px;color:rgb(var(--dyte-colors-text-1000, 255 255 255))}h3{margin:var(--dyte-space-0, 0px);display:flex;height:var(--dyte-space-12, 48px);align-items:center;justify-content:center;font-size:16px;font-weight:400;color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));text-align:center}.chat-container{box-sizing:border-box;display:flex;flex-direction:column;padding-top:var(--dyte-space-4, 16px);padding-bottom:var(--dyte-space-4, 16px);flex:1 0 0px;overflow-y:scroll}.chat-container .spacer{flex:1 1 auto}.chat-container .chat{flex:0 0 auto}.chat-input{z-index:10;box-sizing:border-box;display:flex;flex-direction:column;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity));border-top:var(--dyte-border-width-sm, 1px) solid rgb(var(--dyte-colors-background-600, 60 60 60))}textarea{box-sizing:border-box;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity));padding:var(--dyte-space-3, 12px);color:rgb(var(--dyte-colors-text-1000, 255 255 255))}textarea::-moz-placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}textarea:-ms-input-placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}textarea::placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}textarea{outline:2px solid transparent;outline-offset:2px;resize:none;overflow:hidden;border-width:var(--dyte-border-width-none, 0);border-style:none;font-family:var(--dyte-font-family, sans-serif);min-height:80px;font-size:14px}.chat-buttons{display:flex;align-items:center;justify-content:space-between;padding-left:var(--dyte-space-3, 12px);padding-right:var(--dyte-space-3, 12px);padding-top:var(--dyte-space-2, 8px);padding-bottom:var(--dyte-space-2, 8px)}.chat-buttons .left dyte-button{margin-right:var(--dyte-space-1, 4px)}.chat-buttons .left dyte-button dyte-icon{height:var(--dyte-space-5, 20px);width:var(--dyte-space-5, 20px)}.chat-buttons>div{display:flex;align-items:center}.file-picker{display:none}.chat *:first-child{margin-top:var(--dyte-space-0, 0px)}.chat .head{display:flex;align-items:center}.chat .head .name{margin-right:var(--dyte-space-4, 16px);font-size:12px;font-weight:700}.chat .head .time{font-size:12px;color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}.chat .body{margin-top:var(--dyte-space-2, 8px);margin-bottom:var(--dyte-space-2, 8px);overflow-wrap:break-word;font-size:14px;line-height:1.25rem}.chat .body .emoji{font-size:24px}p{margin-top:var(--dyte-space-0, 0px);margin-bottom:var(--dyte-space-3, 12px)}dyte-text-message,dyte-image-message,dyte-file-message{margin-top:var(--dyte-space-4, 16px);display:block;padding-left:var(--dyte-space-3, 12px);padding-right:var(--dyte-space-3, 12px);font-family:var(--dyte-font-family, sans-serif);color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));box-sizing:border-box}*[is-continued]{margin-top:var(--dyte-space-3, 12px)}dyte-text-message[is-continued]{margin-top:var(--dyte-space-2, 8px)}.chat .image{position:relative;height:var(--dyte-space-40, 160px);max-width:var(--dyte-space-64, 256px);cursor:pointer}.chat .image img{display:none;height:100%;width:100%;border-radius:var(--dyte-border-radius-sm, 4px);-o-object-fit:cover;object-fit:cover}.chat .image .image-spinner{display:flex;height:100%;width:100%;flex-direction:column;align-items:center;justify-content:center;border-radius:var(--dyte-border-radius-sm, 4px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity))}.chat .image .image-spinner dyte-spinner{--tw-text-opacity:1;color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-text-opacity))}.chat .image .image-errored{display:flex;height:100%;width:100%;flex-direction:column;align-items:center;justify-content:center;border-radius:var(--dyte-border-radius-sm, 4px);background-color:rgba(var(--dyte-colors-danger, 255 45 45) / 0.1);--tw-text-opacity:1;color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-text-opacity))}.chat .image .actions{display:none;height:var(--dyte-space-8, 32px);align-items:center;position:absolute;top:var(--dyte-space-2, 8px);right:var(--dyte-space-2, 8px);border-radius:var(--dyte-border-radius-sm, 4px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255));overflow:hidden;--tw-shadow:0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 10px 15px -3px var(--tw-shadow-color), 0 4px 6px -4px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.chat .image .actions .action{height:var(--dyte-space-8, 32px);width:var(--dyte-space-8, 32px);border-radius:var(--dyte-border-radius-none, 0);border-width:var(--dyte-border-width-none, 0);border-style:none;background-color:transparent;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.chat .image .actions .action:hover{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}.image.loaded img{display:block}.image.loaded .image-spinner{display:none}.image:hover .actions,.image:focus .actions{display:flex}.chat .file{display:flex;align-items:center;padding-left:var(--dyte-space-2, 8px);padding-right:var(--dyte-space-2, 8px);padding-top:var(--dyte-space-1\\.5, 6px);padding-bottom:var(--dyte-space-1\\.5, 6px);border-radius:var(--dyte-border-radius-sm, 4px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64))}.chat .file .file-data{flex:1 1 0%}.chat .file .file-data .name{color:rgb(var(--dyte-colors-text-1000, 255 255 255))}.chat .file .file-data .file-data-split{margin-top:var(--dyte-space-0\\.5, 2px);display:flex;align-items:center;font-size:12px}.chat .file .file-data .file-data-split .ext{margin-right:var(--dyte-space-2, 8px);text-transform:uppercase}.chat .file .file-data .file-data-split .divider{height:var(--dyte-space-4, 16px);width:var(--dyte-space-0\\.5, 2px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}.chat .file .file-data .file-data-split .size{margin-left:var(--dyte-space-2, 8px)}a{--tw-text-opacity:1;color:rgba(var(--dyte-colors-brand-300, 73 124 253) / var(--tw-text-opacity));-webkit-text-decoration-line:none;text-decoration-line:none}a:hover{-webkit-text-decoration-line:underline;text-decoration-line:underline}#dropzone{position:absolute;top:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);z-index:10;display:none;flex-direction:column;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64))}#dropzone.active{display:flex;-webkit-animation:0.3s slide-up ease;animation:0.3s slide-up ease}@-webkit-keyframes slide-up{from{transform:translateY(100%)}to{transform:translateY(0%)}}@keyframes slide-up{from{transform:translateY(100%)}to{transform:translateY(0%)}}dyte-emoji-picker{z-index:0;border-top:var(--dyte-border-width-sm, 1px) solid rgb(var(--dyte-colors-background-600, 60 60 60));-webkit-animation:0.3s slide-up ease;animation:0.3s slide-up ease}";

const DyteChat$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.chat = [];
    this.shiftDown = false;
    this.now = new Date();
    this.autoScrollEnabled = false;
    this.dropzoneActivated = false;
    this.canSend = false;
    this.canSendTextMessage = false;
    this.canSendFiles = false;
    this.emojiPickerEnabled = false;
    this.toggleEmojiPicker = () => {
      this.emojiPickerEnabled = !this.emojiPickerEnabled;
    };
    this.persistTextMessage = (e) => {
      const message = e.target.value;
      gracefulStorage.setItem('dyte-text-message', message);
    };
    this.initialiseTextField = (el) => {
      this.textArea = el;
      const message = gracefulStorage.getItem('dyte-text-message') || '';
      this.textArea.value = message;
    };
    this.onEmojiClicked = (e) => {
      this.textArea.value = this.textArea.value + e.detail;
      this.textArea.focus();
    };
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    const prefs = getUserPreferences();
    this.autoScrollEnabled = prefs.autoScroll;
    this.host.addEventListener('dragover', (e) => {
      e.preventDefault();
      this.dropzoneActivated = true;
    });
    this.host.addEventListener('dragleave', () => {
      this.dropzoneActivated = false;
    });
    this.host.addEventListener('drop', (e) => {
      e.preventDefault();
      this.dropzoneActivated = false;
      this.handleFilesDataTransfer(e.dataTransfer.items);
    });
  }
  componentDidRender() {
    if (this.autoScrollEnabled) {
      smoothScrollToBottom(this.chatEl);
    }
  }
  disconnectedCallback() {
    var _a;
    this.timeout && clearTimeout(this.timeout);
    typeof this.request === 'number' && cancelAnimationFrame(this.request);
    this.chatUpdateListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.chat.removeListener('chatUpdate', this.chatUpdateListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canSend = meeting.self.permissions.chatPublic.canSend;
      this.canSendTextMessage = meeting.self.permissions.chatPublic.text;
      this.canSendFiles = meeting.self.permissions.chatPublic.files;
      this.chat = meeting.chat.messages.map((message) => ({ type: 'chat', message }));
      this.chatUpdateListener = ({ message }) => {
        if (message != null) {
          this.chat = [...this.chat, { type: 'chat', message }];
        }
      };
      // update current time every minute
      const updateNow = () => {
        this.now = new Date();
        this.timeout = setTimeout(() => {
          if (this.request != null) {
            this.request = requestAnimationFrame(updateNow);
          }
        }, 60 * 1000);
      };
      this.request = requestAnimationFrame(updateNow);
      meeting.chat.addListener('chatUpdate', this.chatUpdateListener);
    }
  }
  handleSendMessage() {
    var _a;
    if (!this.canSend || !this.canSendTextMessage) {
      return;
    }
    const message = this.textArea.value.trim();
    if (message.length > 0) {
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.chat.sendTextMessage(message);
      this.textArea.value = '';
      this.textArea.style.height = 'auto';
      gracefulStorage.setItem('dyte-text-message', '');
    }
  }
  handleKeyDown(e) {
    // slack like typing experience
    if (e.key === 'Shift') {
      this.shiftDown = true;
    }
    else if (e.key === 'Enter' && this.shiftDown) {
      const height = this.textArea.clientHeight;
      if (height < 240) {
        this.textArea.style.height = this.textArea.clientHeight + 20 + 'px';
      }
    }
    else if (e.key === 'Enter') {
      e.preventDefault();
      this.handleSendMessage();
    }
    else if (e.key === 'Backspace') {
      if (this.textArea.value.endsWith('\n')) {
        this.textArea.style.height = this.textArea.clientHeight - 20 + 'px';
      }
      else if (this.textArea.value === '') {
        this.textArea.style.height = 'auto';
      }
    }
  }
  handleKeyUp(e) {
    if (e.key === 'Shift') {
      this.shiftDown = false;
    }
  }
  uploadFile(type) {
    const input = document.createElement('input');
    input.type = 'file';
    if (type === 'image') {
      input.accept = 'image/*';
    }
    input.onchange = (e) => {
      const { validity, files: [file], } = e.target;
      if (validity.valid) {
        this.sendFile(file, type);
      }
    };
    input.click();
  }
  handleFilesDataTransfer(items) {
    if (items == null)
      return;
    for (const item of items) {
      if (item.kind === 'file') {
        const file = item.getAsFile();
        if (item.type.startsWith('image/')) {
          this.sendFile(file, 'image');
        }
        else {
          this.sendFile(file, 'file');
        }
      }
    }
  }
  sendFile(file, type) {
    var _a, _b;
    if (!this.canSend || !this.canSendFiles) {
      return;
    }
    if (type === 'image') {
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.chat.sendImageMessage(file);
    }
    else {
      (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.chat.sendFileMessage(file);
    }
  }
  toggleAutoScroll(scrollState) {
    this.autoScrollEnabled = scrollState;
    setPreference('auto-scroll', scrollState);
  }
  render() {
    let prevMessage = null;
    return (h(Host, null, h("div", { id: "dropzone", class: { active: this.dropzoneActivated }, part: "dropzone" }, h("dyte-icon", { icon: this.iconPack.attach }), h("p", null, this.t('Drop files/images to send'))), h("div", { class: "chat-container scrollbar", ref: (el) => (this.chatEl = el), part: "container" }, h("div", { class: "spacer", part: "spacer" }), h("div", { class: "chat", part: "chat" }, this.chat.map((item) => {
      if (item.type === 'chat') {
        const { message } = item;
        const isContinued = message.userId === (prevMessage === null || prevMessage === void 0 ? void 0 : prevMessage.userId) &&
          differenceInMinutes(message.time, prevMessage === null || prevMessage === void 0 ? void 0 : prevMessage.time) < 2;
        prevMessage = message;
        switch (message.type) {
          case 'text':
            return (h("dyte-text-message", { message: message, now: this.now, isContinued: isContinued }));
          case 'image':
            return (h("dyte-image-message", { message: message, now: this.now, isContinued: isContinued, iconPack: this.iconPack }));
          case 'file':
            return (h("dyte-file-message", { message: message, now: this.now, isContinued: isContinued, iconPack: this.iconPack }));
        }
      }
    }))), this.canSend && this.canSendTextMessage && this.emojiPickerEnabled && (h("dyte-emoji-picker", { t: this.t, onDyteEmojiClicked: this.onEmojiClicked, part: "emoji-picker" })), h("form", { class: "chat-input", part: "chat-input" }, this.canSend && this.canSendTextMessage && (h("textarea", { placeholder: "Message..", ref: this.initialiseTextField, onKeyDown: (e) => this.handleKeyDown(e), onKeyUp: (e) => this.handleKeyUp(e), onInput: this.persistTextMessage, autoFocus: true, onPaste: (e) => {
        const data = e.clipboardData || e.originalEvent.clipboardData;
        this.handleFilesDataTransfer(data.items);
      }, part: "textarea" })), h("div", { class: "chat-buttons", part: "chat-buttons" }, h("div", { class: "left", part: "chat-buttons-left" }, h("dyte-tooltip", { size: this.size, label: this.t(this.autoScrollEnabled ? 'Autoscroll enabled' : 'Autoscroll disabled') }, h("dyte-button", { variant: "ghost", kind: "icon", onClick: () => this.toggleAutoScroll(!this.autoScrollEnabled), title: this.t(this.autoScrollEnabled ? 'Autoscroll enabled' : 'Autoscroll disabled') }, h("dyte-icon", { icon: this.autoScrollEnabled
        ? this.iconPack.vertical_scroll
        : this.iconPack.vertical_scroll_disabled }))), this.canSend &&
      this.canSendFiles && [
      h("dyte-tooltip", { label: this.t('Send a file'), size: this.size }, h("dyte-button", { variant: "ghost", kind: "icon", onClick: () => this.uploadFile('file'), title: this.t('Send a file') }, h("dyte-icon", { icon: this.iconPack.attach }))),
      h("dyte-tooltip", { label: this.t('Send an image'), size: this.size }, h("dyte-button", { variant: "ghost", kind: "icon", onClick: () => this.uploadFile('image'), title: this.t('Send an image') }, h("dyte-icon", { icon: this.iconPack.image }))),
    ], this.canSend && this.canSendTextMessage && (h("dyte-tooltip", { label: this.t('Send Emoji'), size: this.size }, h("dyte-button", { variant: "ghost", kind: "icon", class: { active: this.emojiPickerEnabled }, title: this.t('Send Emoji'), onClick: this.toggleEmojiPicker }, h("dyte-icon", { icon: this.iconPack.emoji_multiple }))))), this.canSend && this.canSendTextMessage && (h("div", { class: "right", part: "chat-buttons-right" }, h("dyte-tooltip", { variant: "primary", label: this.t('Send message'), size: this.size, delay: 2000 }, h("dyte-button", { kind: "icon", onClick: () => this.handleSendMessage(), title: this.t('Send message') }, h("dyte-icon", { icon: this.iconPack.send })))))))));
  }
  get host() { return this; }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteChatCss; }
}, [1, "dyte-chat", {
    "meeting": [16],
    "config": [16],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "chat": [32],
    "shiftDown": [32],
    "now": [32],
    "autoScrollEnabled": [32],
    "dropzoneActivated": [32],
    "canSend": [32],
    "canSendTextMessage": [32],
    "canSendFiles": [32],
    "emojiPickerEnabled": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-chat", "dyte-button", "dyte-emoji-picker", "dyte-file-message", "dyte-icon", "dyte-image-message", "dyte-spinner", "dyte-text-message", "dyte-tooltip"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-chat":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteChat$1);
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "dyte-emoji-picker":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "dyte-file-message":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "dyte-image-message":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "dyte-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "dyte-text-message":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-tooltip":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteChat = DyteChat$1;
const defineCustomElement = defineCustomElement$1;

export { DyteChat, defineCustomElement };
