import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { u as useLanguage } from './index2.js';
import { d as defaultIconPack } from './default-icon-pack.js';
import { s as state } from './store.js';
import { d as defineCustomElement$2 } from './dyte-button2.js';

const dyteLeaveMeetingCss = ".leave-modal{position:relative;display:flex;flex-direction:column;border-radius:var(--dyte-border-radius-md, 8px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity));padding:var(--dyte-space-4, 16px);color:rgb(var(--dyte-colors-text-1000, 255 255 255))}.leave-modal .header h2{margin:var(--dyte-space-0, 0px)}.leave-modal .content{font-size:14px}.leave-message p{margin-top:var(--dyte-space-3, 12px);margin-bottom:var(--dyte-space-3, 12px)}.leave-meeting{display:flex;flex-direction:row;justify-content:space-between;gap:var(--dyte-space-2, 8px)}.leave-meeting dyte-button{flex:1 1 0%}.end-meeting{margin-top:var(--dyte-space-2, 8px)}";

const DyteLeaveMeeting$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    this.keyPressListener = (e) => {
      if (e.key === 'Escape') {
        this.close();
      }
    };
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.canEndMeeting = false;
    this.close = () => {
      this.stateUpdate.emit({ activeLeaveConfirmation: false });
      state.activeLeaveConfirmation = false;
    };
    this.handleLeave = () => {
      var _a;
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.leaveRoom();
      this.close();
    };
    this.handleEndMeeting = () => {
      var _a;
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.participants.kickAll();
      this.close();
    };
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    document.addEventListener('keydown', this.keyPressListener);
  }
  componentDidLoad() { }
  disconnectedCallback() {
    document.removeEventListener('keydown', this.keyPressListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canEndMeeting = meeting.self.permissions.kickParticipant;
    }
  }
  render() {
    return (h(Host, null, h("div", { class: "leave-modal" }, h("div", { class: "header" }, h("h2", { class: "title" }, this.t('leave'))), h("p", { class: "message" }, this.t('leave_confirmation')), h("div", { class: "content" }, h("div", { class: "leave-meeting" }, h("dyte-button", { variant: "secondary", title: this.t('Close'), onClick: this.close }, this.t('cancel')), h("dyte-button", { variant: "danger", title: this.t('leave'), onClick: this.handleLeave }, this.t('leave'))), this.canEndMeeting && (h("div", { class: "end-meeting" }, h("dyte-button", { variant: "danger", kind: "wide", onClick: this.handleEndMeeting }, this.t('end_meeting_for_all'))))))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteLeaveMeetingCss; }
}, [1, "dyte-leave-meeting", {
    "meeting": [16],
    "states": [16],
    "iconPack": [16],
    "t": [16],
    "canEndMeeting": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-leave-meeting", "dyte-button"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-leave-meeting":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteLeaveMeeting$1);
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteLeaveMeeting = DyteLeaveMeeting$1;
const defineCustomElement = defineCustomElement$1;

export { DyteLeaveMeeting, defineCustomElement };
